Aperture Macros
===============

.. autoclass:: gerbonara.aperture_macros.parse.ApertureMacro
    :members:

.. autoclass:: gerbonara.aperture_macros.expression.Expression
    :members:

.. autoclass:: gerbonara.aperture_macros.expression.UnitExpression
    :members:

.. autoclass:: gerbonara.aperture_macros.expression.ConstantExpression
    :members:

.. autoclass:: gerbonara.aperture_macros.expression.VariableExpression
    :members:

.. autoclass:: gerbonara.aperture_macros.expression.OperatorExpression
    :members:

.. autoclass:: gerbonara.aperture_macros.primitive.Primitive
    :members:

.. autoclass:: gerbonara.aperture_macros.primitive.Circle
    :members:

.. autoclass:: gerbonara.aperture_macros.primitive.VectorLine
    :members:

.. autoclass:: gerbonara.aperture_macros.primitive.CenterLine
    :members:

.. autoclass:: gerbonara.aperture_macros.primitive.Polygon
    :members:

.. autoclass:: gerbonara.aperture_macros.primitive.Thermal
    :members:

.. autoclass:: gerbonara.aperture_macros.primitive.Outline
    :members:

.. autoclass:: gerbonara.aperture_macros.primitive.Comment
    :members:

